@@ -123,7 +123,7 @@ from ae.kivy_glsl import ShaderIdType, ShadersMixin
 from ae.kivy_relief_canvas import ReliefCanvas                                                          # type: ignore
 
 
-__version__ = '0.1.19'
+__version__ = '0.1.22'
 
 
 # load/declared help/tour widgets, based-on Kivy core widgets (without any features from ae.kivy_app/widgets.kv)
@@ -244,13 +244,18 @@ Builder.load_string("""\
     explained_widget: tooltip.explained_widget
     explained_pos:
         root.explained_widget.to_window(*root.explained_widget.pos) \
-        or root.explained_widget or root.explained_widget.pos
-    font_height: app.main_app.font_size * 1.8
-    label_height: app.main_app.font_size * 2.1
+        or root.explained_widget or app.app_states['font_size']
+        # font_size binding needed for user preferences animation
+    font_height: app.main_app.font_size
+    label_height: root.font_height * 1.2
+    page_text_padding: round(min(self.width, self.height) / 18.6) if root.title_text or root.page_text else 0.0
     title_text: ""
-    title_size: app.main_app.text_size_guess(root.title_text, font_size=root.font_height)
+    title_size:
+        app.main_app.text_size_guess(root.title_text,
+        font_size=title_lbl.font_size,
+        padding=2 * (root.page_text_padding,))
     page_text: ""
-    page_size: app.main_app.text_size_guess(root.page_text)
+    page_size: app.main_app.text_size_guess(root.page_text, padding=2 * (root.page_text_padding, ))
     tip_text: tooltip.tip_text
     next_text: _('next')
     prev_text: _('back')
@@ -277,47 +282,69 @@ Builder.load_string("""\
         opacity: 1.0 if root.tip_text else 0.0
     TourPageTexts:
         id: tour_page_texts
+        padding: root.page_text_padding
+        relief_square_inner_lines: root.page_text_padding
         height:
             (2.01 * self.padding[0] if title_lbl.height or page_lbl.height else 0) + \
             (max(title_lbl.height, page_lbl.height) if app.landscape else title_lbl.height + page_lbl.height)
         pos_hint: dict(x=0, y=root.navigation_pos_hint_y)
+        canvas.before:
+            Color:
+                rgba: 0.99, 0, 0, 0.24
+            Rectangle:
+                pos: self.pos
+                size: self.size
         Label:
             id: title_lbl
+            padding: 2 * (root.page_text_padding, )
             size_hint:
                 0.003 if not self.text or root.title_size[0] == 0 else \
                 (0.99 / (0.99 + root.page_size[0] / root.title_size[0])) if app.landscape else \
                 0.99, None
-            text_size: self.width, None
+            text_size: self.width - root.page_text_padding, None
             halign: 'center'
-            height: max(root.title_size[1], root.page_size[1] if app.landscape else 0)
+            height: max(self.texture_size[1], page_lbl.texture_size[1] if app.landscape else 0)
             color: app.font_color
-            font_size: root.font_height
+            font_size: root.font_height * 1.5
             markup: True
             text: root.title_text
+            canvas.before:
+                Color:
+                    rgba: 0, 0.99, 0, 0.3
+                Rectangle:
+                    pos: self.pos
+                    size: self.size
         Label:
             id: page_lbl
+            padding: 2 * (root.page_text_padding, )
             size_hint:
                 0.003 if not self.text or root.page_size[0] == 0 else \
                 (0.99 / (0.99 + root.title_size[0] / root.page_size[0])) if app.landscape else \
                 0.99, None
-            text_size: self.width, None
-            halign: 'center'
-            height: max(root.title_size[1] if app.landscape else 0, root.page_size[1])
+            text_size: self.width - root.page_text_padding, None
+            halign: 'left'
+            height: max(title_lbl.texture_size[1] if app.landscape else 0, self.texture_size[1])
             color: app.font_color
-            font_size: app.main_app.font_size
+            font_size: root.font_height
             markup: True
             text: root.page_text
+            canvas.before:
+                Color:
+                    rgba: 0, 0.69, 0.99, 0.3
+                Rectangle:
+                    pos: self.pos
+                    size: self.size
     SwitchPageButton:
         id: prev_but
         disabled: root.navigation_disabled or not root.prev_text
+        pos_hint: dict(x=0.06, top=root.navigation_pos_hint_y)
         size: self.texture_size[0] * 2.1, root.label_height
         font_size: root.font_height
-        pos_hint: dict(x=0.06, top=root.navigation_pos_hint_y)
         text: root.prev_text
         on_release: root.prev_page()
     StopTourButton:
         size_hint: None, None
-        size: 2 * (root.label_height * (1.2 if root.prev_text or root.next_text else 1.8), )
+        size: 2 * (root.label_height * (1.02 if root.prev_text or root.next_text else 1.29), )
         pos_hint:
             dict(center_x=0.501, y=(tour_page_texts.top + self.relief_ellipse_outer_lines) / Window.height) \
             if tour_page_texts.height and tour_page_texts.top + self.height < Window.height else \
@@ -327,9 +354,8 @@ Builder.load_string("""\
     SwitchPageButton:
         id: next_but
         disabled: root.navigation_disabled or not root.next_text
-        #size: self.texture_size[0] + sp(69), root.label_height
-        size: self.texture_size[0] * 2.1, root.label_height
         pos_hint: dict(right=0.939, top=root.navigation_pos_hint_y)
+        size: self.texture_size[0] * 2.1, root.label_height
         font_size: root.font_height
         text: root.next_text
         on_release: root.next_page()
@@ -363,8 +389,8 @@ Builder.load_string("""\
 
 <SwitchPageButton@ButtonBehavior+ShadersMixin+ReliefCanvas+Label>
     opacity: 1.0 if self.text else 0.0
-    size_hint: None, None
     color: app.font_color
+    size_hint: None, None
     relief_ellipse_inner_colors: relief_colors(app.font_color)
     relief_ellipse_inner_lines: round(self.height / 9.6)
     relief_ellipse_inner_offset: -1
@@ -378,11 +404,9 @@ Builder.load_string("""\
 <TourPageTexts@ReliefCanvas+ShadersMixin+BoxLayout>
     orientation: 'horizontal' if app.landscape else 'vertical'
     size_hint_y: None
-    padding: round(self.height / 18.6)
     relief_square_outer_colors: relief_colors(Window.clearcolor)
-    relief_square_outer_lines: sp(99)
+    relief_square_outer_lines: max(self.y, Window.height - self.top)
     relief_square_inner_colors: relief_colors(app.font_color)
-    relief_square_inner_lines: self.padding[0]
     relief_square_inner_offset: -1
     canvas.before:
         Color:
@@ -613,12 +637,31 @@ class AnimatedTourMixin:
 
     the key of this dict is the page id or None (for animations available in all pages of this tour).
     the value of this dict is a tuple of tuples of widget id and animation instances.
+
+    if the first character of the widget id is a `@` then the :attr:`~kivy.animation.Animation.repeat` attribute of
+    the :class:`~kivy.animation.Animation` class will be set to True. the rest of the widget id string specifies the
+    widget to be animated which is either:
+
+    * one of the widgets of the :class:`TourOverlay` layout class, like `tooltip`, `tour_page_texts`, `title_lbl`,
+      `page_lbl`, `prev_but` or `next_but`.
+    * the explained widget if an empty string is given.
+    * the :class:`TourOverlay` layout class instance for any other string.
     """
+
     pages_shaders: Dict[Optional[str], Tuple[Tuple[str, ShaderIdType], ...]]
     """ statically declarable class attribute dict of widget shaders for the pages of this tour.
 
     the key of this dict is the page id or None (for shaders available in all pages of this tour).
-    the value of this dict is a tuple of tuples of widget id and shader id-dicts/add_shader()-kwargs.
+    the value of this dict is a tuple of tuples of widget id and add_shader()-kwargs.
+
+    the widget id string specifies the widget to which a shader will be added, which is either:
+
+    * one of the widgets of the :class:`TourOverlay` layout class, like `tooltip`, `tour_page_texts`, `title_lbl`,
+      `page_lbl`, `prev_but` or `next_but`.
+    * the explained widget if an empty string is given.
+    * the :class:`TourOverlay` layout class instance for any other string.
+
+    the add_shader()-kwargs dict will directly be passed to the :meth:`~ae.kivy_glsl.ShadersMixin.add_shader` method).
     """
 
     _added_animations: List[Tuple[Widget, Animation]]
@@ -632,26 +675,12 @@ class AnimatedTourMixin:
 
     def _evaluated_shader_kwargs(self, shader_kwargs: dict) -> dict:
         tour_shader_kwargs = deepcopy(shader_kwargs)
-        glo_vars = self.main_app.global_variables(layout=self.layout, sp=sp, tour=self, Clock=Clock)
+        glo_vars = self.main_app.global_variables(layout=self.layout, sp=sp, tour=self, Clock=Clock, Window=Window)
         for key, arg in tour_shader_kwargs.items():
             if isinstance(arg, str) and key not in ('add_to', 'render_shape', 'shader_code', 'shader_file'):
                 tour_shader_kwargs[key] = try_eval(arg, glo_vars=glo_vars)
         return tour_shader_kwargs
 
-    def next_page(self):
-        """ overridden to teardown shaders from current page and setup shaders for next page. """
-        self.teardown_animations()
-        # noinspection PyUnresolvedReferences
-        super().next_page()                                                                 # pylint: disable=no-member
-        self.setup_animations()
-
-    def prev_page(self):
-        """ overridden to teardown shaders from current page and setup shaders for previous page. """
-        self.teardown_animations()
-        # noinspection PyUnresolvedReferences
-        super().prev_page()                                                                 # pylint: disable=no-member
-        self.setup_animations()
-
     def setup_animations(self):
         """ setup shaders specified in class attribute :attr:`~AnimatedTourMixin.pages_shaders`. """
         layout = self.layout
@@ -660,7 +689,7 @@ class AnimatedTourMixin:
         pages_shaders = self.pages_shaders.get(None, ()) + self.pages_shaders.get(page_id, ())
         added = list()
         for wid_id, shader_kwargs in pages_shaders:
-            wid = layout.ids.get(wid_id, layout)
+            wid = layout.ids.get(wid_id, layout) if wid_id else self.layout.explained_widget
             added.append((wid, wid.add_shader(**self._evaluated_shader_kwargs(shader_kwargs))))
         self._added_shaders = added
 
@@ -669,28 +698,22 @@ class AnimatedTourMixin:
         for wid_id, anim in pages_animations:
             if isinstance(anim, str):
                 glo_vars = self.main_app.global_variables(layout=self.layout, sp=sp, tour=self,
-                                                          A=Animation, Animation=Animation, Clock=Clock)
+                                                          A=Animation, Animation=Animation, Clock=Clock, Window=Window)
                 anim = try_eval(anim, glo_vars=glo_vars)
             if wid_id[0] == '@':
                 wid_id = wid_id[1:]
                 anim.repeat = True
-            wid = layout.ids.get(wid_id, layout)
+            wid = layout.ids.get(wid_id, layout) if wid_id else self.layout.explained_widget
             anim.start(wid)
             added.append((wid, anim))
         self._added_animations = added
 
-    def start(self):
-        """ overridden to setup shaders for first tour page. """
+    def setup_layout(self):
+        """ overridden to setup animations and shaders of the current tour page. """
         # noinspection PyUnresolvedReferences
-        super().start()                                                                     # pylint: disable=no-member
+        super().setup_layout()                                                              # pylint: disable=no-member
         self.setup_animations()
 
-    def stop(self):
-        """ overridden to teardown shaders on tour stop. """
-        self.teardown_animations()
-        # noinspection PyUnresolvedReferences
-        super().stop()                                                                      # pylint: disable=no-member
-
     def teardown_animations(self):
         """ teardown shaders added by :meth:`~AnimatedTourMixin.setup_animations` method for current tour page. """
         for wid, anim in reversed(self._added_animations):
@@ -698,6 +721,12 @@ class AnimatedTourMixin:
         for wid, shader_id in reversed(self._added_shaders):
             wid.del_shader(shader_id)
 
+    def teardown_page(self):
+        """ overridden to teardown the animations of the current/last-shown tour page. """
+        self.teardown_animations()
+        # noinspection PyUnresolvedReferences
+        super().teardown_page()                                                             # pylint: disable=no-member
+
 
 class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
     """ onboarding tour, extended with glsl shaders. """
@@ -708,11 +737,16 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
         ),
         '': (
             ('next_but',
-             "A(font_size=layout.font_height, d=24) + "
-             "A(font_size=sp(12), d=3) + "
-             "A(font_size=sp(69), d=6) + "
-             "A(font_size=layout.font_height, d=3)"),
+             "A(font_size=layout.font_height, t='in_out_sine', d=24) + "
+             "A(font_size=layout.main_app.framework_app.min_font_size, t='in_out_sine', d=3) + "
+             "A(font_size=layout.main_app.framework_app.max_font_size, t='in_out_sine', d=6) + "
+             "A(font_size=layout.font_height, t='in_out_sine', d=3)"),
         ),
+        'layout_font_size': (
+            ('@',
+             "A(value=layout.main_app.framework_app.max_font_size, t='in_out_sine', d=12.9) + "
+             "A(value=layout.main_app.framework_app.min_font_size, t='in_out_sine', d=4.2)"),
+        )
     }
     pages_shaders = {
         '': (
@@ -731,7 +765,7 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
                 shader_code='=plunge_waves',
             )),
         ),
-        'switch_page': (
+        'page_switching': (
             ('root', dict(
                 alpha="lambda: 0.39 * layout.ani_value",
                 center_pos="lambda: list(map(float, layout.ids.prev_but.center))",
@@ -739,6 +773,7 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
                 time="lambda: -Clock.get_boottime()",
                 tint_ink=(0.21, 0.39, 0.09, 0.9),
             )),
+            ('tour_page_texts', dict(add_to='before')),
             ('prev_but', dict(
                 add_to='before',
                 alpha="lambda: 0.12 + layout.ani_value / 3",
@@ -747,7 +782,7 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
                 time="lambda: -Clock.get_boottime()",
             )),
         ),
-        'help_activate': (
+        'tip_help_intro': (
             ('tour_page_texts', dict(
                 add_to='before',
                 alpha="lambda: 0.12 + layout.ani_value / 3",
@@ -769,17 +804,19 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
                 shader_code='=worm_whole',
             )),
         ),
-        'tooltip': (
+        'tip_help_tooltip': (
             ('prev_but', dict(
                 add_to='before',
                 render_shape='Ellipse',
                 shader_code='=fire_storm',
+                tint_ink=(0.81, 0.39, 0.09, 0.39),
                 time="lambda: -Clock.get_boottime()",
             )),
             ('next_but', dict(
                 add_to='before',
                 render_shape='Ellipse',
                 shader_code='=fire_storm',
+                tint_ink=(0.03, 0.03, 0.9, 0.39),
             )),
         ),
         'responsible_layout': (
@@ -809,7 +846,7 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
                 tint_ink=(0.81, 0.39, 0.9, 0.999),
             )),
         ),
-        'stop_tour': (
+        'tour_end': (
             ('tour_page_texts', dict(add_to='before')),
             ('prev_but', dict(
                 add_to='before',
@@ -825,7 +862,7 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
         ),
     }
 
-    _landscape_bound = None
+    _bound = None
 
     def next_page(self):
         """ overriding to remove next button size animation only visible in the first tour after app re/start. """
@@ -842,14 +879,20 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
         super().setup_page()
         page_id = self.page_ids[self.page_idx]
         if page_id == 'responsible_layout':
-            self._landscape_bound = self.main_app.framework_app.fbind('landscape', lambda *_args: self.setup_texts())
+            self._bound = self.main_app.framework_app.fbind('landscape', lambda *_args: self.setup_texts())
+        elif page_id == 'layout_font_size':
+            self._bound = self._added_animations[-1][1].fbind('on_progress', lambda *_args: self.setup_texts())
 
     def teardown_page(self):
         """ overridden to unbind setup_texts() on leaving the responsible_layout tour page. """
         super().teardown_page()
-        page_id = self.page_ids[self.page_idx]
-        if page_id == 'responsible_layout' and self._landscape_bound:
-            self.main_app.framework_app.unbind_uid('landscape', self._landscape_bound)
+        if self._bound:
+            page_id = self.page_ids[self.page_idx]
+            if page_id == 'responsible_layout':
+                self.main_app.framework_app.unbind_uid('landscape', self._bound)
+            elif page_id == 'layout_font_size':
+                self.main_app.framework_app.unbind_uid('on_progress', self._bound)
+            self._bound = None
 
 
 class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
@@ -869,6 +912,10 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
         """
         self.main_app = main_app
         main_app.vpo("TourOverlay.__init__")
+
+        if main_app.onboarding_tour_class is OnboardingTour:
+            main_app.onboarding_tour_class = AnimatedOnboardingTour
+
         self._tooltip_animation = None
         self.auto_dismiss = False
         self.explained_widget = main_app.help_activator             # assign dummy init widget to prevent None errors
@@ -884,20 +931,21 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
         """ switch to next tour page. """
         self.main_app.vpo("TourOverlay.next_page")
         self.navigation_disabled = True
-        self.tour_instance.auto_switch_cancel()
+        self.tour_instance.cancel_auto_page_switch_request()
         self.tour_instance.next_page()
 
     def page_updated(self):
         """ callback from :meth:`~TourBase.setup_layout` for UI-specific patches, after tour layout/overlay setup. """
+        Clock.tick()                        # let Kivy fully update the layout (e.g. for tour_page_texts.height)
         tooltip = self.ids.tooltip
         win_height = Window.height
-        nav_y = self.label_height * 1.8   # default pos_y of navigation bar with prev/next buttons
+        nav_y = self.label_height * 1.29    # default pos_y of navigation bar with prev/next buttons
         if self.main_app.widget_visible(tooltip):
             exp_y = self.explained_pos[1]
             pos1 = min(exp_y, tooltip.y)
             pos2 = max(exp_y + self.explained_widget.height, tooltip.top)
             if pos1 < win_height - pos2:
-                nav_y += pos2
+                nav_y = max(nav_y + pos2, win_height - self.ids.tour_page_texts.height)
         Animation(navigation_pos_hint_y=nav_y / win_height, t='in_out_sine', d=3).start(self)
 
         self.navigation_disabled = False
@@ -906,6 +954,7 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
         """ switch to previous tour page. """
         self.main_app.vpo("TourOverlay.prev_page")
         self.navigation_disabled = True
+        self.tour_instance.cancel_auto_page_switch_request()
         self.tour_instance.prev_page()
 
     def start_tour(self, tour_cls: Optional[Type[TourBase]] = None) -> bool:
@@ -916,7 +965,7 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
         """
         main_app = self.main_app
         if tour_cls is None:
-            tour_cls = help_id_tour_class(main_app.displayed_help_id) or AnimatedOnboardingTour
+            tour_cls = help_id_tour_class(main_app.displayed_help_id) or main_app.onboarding_tour_class
         main_app.vpo(f"TourOverlay.start_tour tour_cls={tour_cls.__name__}")
 
         try:
